pub struct ParameterData {
pub name: String,
pub description: Option<String>,
pub required: bool,
pub deprecated: Option<bool>,
pub format: ParameterSchemaOrContent,
pub example: Option<Value>,
pub examples: IndexMap<String, Ref<Example>>,
pub explode: Option<bool>,
pub extensions: IndexMap<String, Value>,
}Expand description
Describes a single operation parameter.
A unique parameter is defined by a combination of a name and location.
Fields
name: StringREQUIRED. The name of the parameter. Parameter names are case sensitive. If in is “path”, the name field MUST correspond to the associated path segment from the path field in the Paths Object. See Path Templating for further information.
If in is “header” and the name field is “Accept”, “Content-Type” or “Authorization”, the parameter definition SHALL be ignored.
For all other cases, the name corresponds to the parameter name used by the in property.
description: Option<String>A brief description of the parameter. This could contain examples of use. CommonMark syntax MAY be used for rich text representation.
required: boolDetermines whether this parameter is mandatory. If the parameter location is “path”, this property is REQUIRED and its value MUST be true. Otherwise, the property MAY be included and its default value is false.
deprecated: Option<bool>Specifies that a parameter is deprecated and SHOULD be transitioned out of usage.
format: ParameterSchemaOrContentexample: Option<Value>examples: IndexMap<String, Ref<Example>>explode: Option<bool>extensions: IndexMap<String, Value>Inline extensions to this object.
Implementations